@@ -16,7 +16,7 @@ use vars qw($VERSION $AUTOLOAD @ISA $AUTO_ADD);
 
 require 5.008;
 
-$VERSION = '1.48';
+$VERSION = '1.58';
 
 $AUTO_ADD = 0;
 
@@ -463,7 +463,7 @@ sub _get_encode_cb_params
 {
     my $self = shift;
 
-    return 
+    return
         defined($self->{encode_cb}) ?
             ("encode_cb" => $self->{encode_cb}) :
             ()
@@ -625,7 +625,7 @@ sub _is_rdf_resource {
     {
         $ns = $self->_parser->namespace($el);
     }
-    
+
     return (
            exists($self->_rdf_resource_fields->{ $ns })
         && exists($self->_rdf_resource_fields->{ $ns }{ $el })
@@ -922,7 +922,7 @@ sub _handle_start {
     my $parser = $self->_parser;
 
     my ($el_ns, $el_verdict) = $self->_get_elem_namespace($el);
-    
+
     if ($el eq "image")
     {
         if (exists($attribs{'resource'}))
@@ -993,6 +993,11 @@ sub _handle_start {
     elsif ($self->_start_array_element("skipDays", $el)) {
         # Do nothing - already done in the predicate.
     }
+    elsif ($el eq 'cloud') {
+        if (keys %attribs) {
+            $self->{channel}{cloud} = \%attribs;
+        }
+    }
     elsif ($el eq 'item') {
 
         # deal with trouble makers who use mod_content :)
@@ -1018,16 +1023,14 @@ sub _handle_start {
     }
     elsif ($el eq 'guid') {
         $self->_last_item->{'isPermaLink'} =
-          (exists($attribs{'isPermaLink'}) && 
-              (lc($attribs{'isPermaLink'}) eq 'true')
-          );
+          ( (!exists($attribs{'isPermaLink'})) || (lc($attribs{'isPermaLink'}) ne 'false') );
 
         # beginning of taxo li element in item element
         #'http://purl.org/rss/1.0/modules/taxonomy/' => 'taxo'
     }
     elsif (
            $self->_current_element eq "item"
-        && (($el eq "category") || 
+        && (($el eq "category") ||
             (
                    exists($self->{modules}->{$el_ns})
                 && ($self->{modules}->{$el_ns} eq "dc")
@@ -1066,8 +1069,8 @@ sub _handle_start {
     }
 
     # beginning of a channel element that stores its info in rdf:resource
-    elsif ( $parser->namespace($el) 
-        && $self->_is_rdf_resource($el) 
+    elsif ( $parser->namespace($el)
+        && $self->_is_rdf_resource($el)
         && $self->_current_element eq 'channel')
     {
         my $ns = $parser->namespace($el);
@@ -1140,7 +1143,7 @@ sub _handle_start {
     }
     elsif ($self->_start_array_element("image", $el)) {
         # Do nothing - already done in the predicate.
-    }    
+    }
     elsif (($el eq "category") &&
         (!$parser->within_element("item")) &&
         $self->_start_array_element("channel", $el)) {
@@ -1151,7 +1154,7 @@ sub _handle_start {
            {
         # Make sure an opening tag signifies that the element has been
         # encountered.
-        if (   exists($self->{'channel'}->{$el}) 
+        if (   exists($self->{'channel'}->{$el})
             && (!defined($self->{'channel'}->{$el})))
         {
             $self->{'channel'}->{$el} = "";
@@ -1262,8 +1265,11 @@ sub _get_parser {
                 # Detach the parser to avoid reference loops.
                 $self->_parser(undef);
             },
+            ExternEnt => sub {
+                return '';
+            },
         }
-    );    
+    );
 }
 
 sub _parse_options {
@@ -1343,7 +1349,7 @@ sub _untaint {
     my $self = shift;
 
     my $value = shift;
-    
+
     my ($untainted) = ($value =~ m{(.*)}s);
 
     return $untainted;
@@ -1600,7 +1606,7 @@ XML::RSS - creates and updates RSS files
         enclosure   => { url=>$url, type=>"application/x-bittorrent" },
         description => 'blah blah'
 );
- 
+
  $rss->textinput(title => "quick finder",
                  description => "Use the text input below to search freshmeat",
                  name  => "query",
@@ -1643,7 +1649,7 @@ XML::RSS - creates and updates RSS files
 
  while (@{$rss->{'items'}} >= 15)
  {
-     pop(@{$rss->{'items'});
+     shift (@{ $rss->{'items'} });
  }
 
  $rss->add_item(title => "MpegTV Player (mtv) 1.0.9.7",
@@ -1675,7 +1681,7 @@ site from sources like Slashdot and Freshmeat or if you want to syndicate
 your own content.
 
 XML::RSS currently supports 0.9, 0.91, and 1.0 versions of RSS.
-See http://backend.userland.com/rss091 for information on RSS 0.91. 
+See http://backend.userland.com/rss091 for information on RSS 0.91.
 See http://www.purplepages.ie/RSS/netscape/rss0.90.html for RSS 0.9.
 See http://web.resource.org/rss/1.0/ for RSS 1.0.
 
@@ -1683,10 +1689,10 @@ RSS was originally developed by Netscape as the format for
 Netscape Netcenter channels, however, many Web sites have since
 adopted it as a simple syndication format. With the advent of RSS 1.0,
 users are now able to syndication many different kinds of content
-including news headlines, threaded measages, products catalogs, etc.
+including news headlines, threaded messages, products catalogs, etc.
 
 B<Note:> In order to parse and generate dates (such as C<pubDate>
-and C<dc:date>) it is recommended to use L<DateTime::Format::Mail> and 
+and C<dc:date>) it is recommended to use L<DateTime::Format::Mail> and
 L<DateTime::Format::W3CDTF> , which is what L<XML::RSS> uses internally
 and requires.
 
@@ -1756,7 +1762,7 @@ be more the 40 characters, the B<link> 500, and the B<description>
 are required for RSS 1.0. B<language> is required for RSS 0.91.
 The other parameters are optional for RSS 0.91 and 1.0.
 
-To retreive the values of the channel, pass the name of the value
+To retrieve the values of the channel, pass the name of the value
 (title, link, or description) as the first and only argument
 like so:
 
@@ -1775,8 +1781,8 @@ is for B<channel()>.
 
 =item parse ($string, \%options)
 
-Parses an RDF Site Summary which is passed into B<parse()> as the first 
-parameter. Returns the instance of the object so one can say 
+Parses an RDF Site Summary which is passed into B<parse()> as the first
+parameter. Returns the instance of the object so one can say
 C<< $rss->parse($string)->other_method() >>.
 
 See the add_module() method for instructions on automatically adding
@@ -1805,9 +1811,9 @@ compatibility.
 
 =item * modules_as_arrays
 
-This option when true, will parse the modules key-value-pairs as an arrayref of 
+This option when true, will parse the modules key-value-pairs as an arrayref of
 C<<< { el => $key_name, value => $value, } >>> hash-refs to gracefully
-handle duplicate items (see below). It will not affect the known modules such 
+handle duplicate items (see below). It will not affect the known modules such
 as dc ("Dublin Core").
 
 =back
@@ -1846,13 +1852,13 @@ to a program on a Web server via an HTML form. B<name> is the HTML form name
 and B<link> is the URL to the program. Content is submitted using the GET
 method.
 
-Access to the B<textinput> values is the the same as B<channel()> and
+Access to the B<textinput> values is the same as B<channel()> and
 B<image()>.
 
 =item add_module(prefix=>$prefix, uri=>$uri)
 
 Adds a module namespace declaration to the XML::RSS object, allowing you
-to add modularity outside of the the standard RSS 1.0 modules.  At present,
+to add modularity outside of the standard RSS 1.0 modules.  At present,
 the standard modules Dublin Core (dc) and Syndication (syn) are predefined
 for your convenience. The Taxonomy (taxo) module is also internally supported.
 
@@ -1899,7 +1905,7 @@ one after the other. For example:
     $rss->add_item (
         title => $title,
         link => $link,
-        dc => { 
+        dc => {
             subject=> ["Jungle", "Desert", "Swamp"],
             creator=>$creator,
             date=>$date
@@ -1935,8 +1941,8 @@ Then proceed as usual:
 
   $rss->add_item (title=>$title, link=>$link, my=>{ rating=>$rating });
 
-You can also set the value of the module's prefix to an array reference 
-of C<<< { el => , val => } >>> hash-references, in which case duplicate 
+You can also set the value of the module's prefix to an array reference
+of C<<< { el => , val => } >>> hash-references, in which case duplicate
 elements are possible:
 
   $rss->add_item(title=>$title, link=>$link, my=> [
@@ -2031,17 +2037,16 @@ parameter to diff.
 
 =head1 SOURCE AVAILABILITY
 
-The source is available from the perl.org Subversion server:
-
-L<http://svn.perl.org/modules/XML-RSS/>
+The source is available from the GitHub repository:
 
+L<https://github.com/shlomif/perl-XML-RSS>
 
 =head1 AUTHOR
 
 Original code: Jonathan Eisenzopf <eisen@pobox.com>
 
-Further changes: Rael Dornfest <rael@oreilly.com>, Ask Bjoern Hansen 
-<ask@develooper.com> 
+Further changes: Rael Dornfest <rael@oreilly.com>, Ask Bjoern Hansen
+<ask@develooper.com>
 
 Currently: Shlomi Fish <shlomif@cpan.org>
 
@@ -2069,7 +2074,7 @@ modify it under the same terms as Perl itself.
  Aaron Straup Cope <asc@vineyard.net>
  Ian Davis <iand@internetalchemy.org>
  rayg@varchars.com
- Shlomi Fish <shlomif@iglu.org.il>
+ Shlomi Fish <shlomif@cpan.org>
 
 =head1 SEE ALSO
 
